@@ -1,6 +1,7 @@
 require 'sidekiq'
 require 'sidekiq/util'
 require 'rufus-scheduler'
+require 'sidekiq/cron/support'
 
 module Sidekiq
   module Cron
@@ -44,12 +45,12 @@ module Sidekiq
       end
 
       #enque cron job to queue
-      def enque! time = Time.now
+      def enque! time = Time.now.utc
         @last_enqueue_time = time
 
         klass_const =
             begin
-              @klass.to_s.constantize
+              Sidekiq::Cron::Support.constantize(@klass.to_s)
             rescue NameError
               nil
             end
@@ -68,12 +69,12 @@ module Sidekiq
           end
         end
 
-        save
+        save_last_enqueue_time
         logger.debug { "enqueued #{@name}: #{@message}" }
       end
 
       def is_active_job?
-        @active_job || defined?(ActiveJob::Base) && @klass.to_s.constantize < ActiveJob::Base
+        @active_job || defined?(ActiveJob::Base) && Sidekiq::Cron::Support.constantize(@klass.to_s) < ActiveJob::Base
       rescue NameError
         false
       end
@@ -256,7 +257,7 @@ module Sidekiq
       attr_reader   :last_enqueue_time, :fetch_missing_args
 
       def initialize input_args = {}
-        args = input_args.stringify_keys
+        args = Hash[input_args.map{ |k, v| [k.to_s, v] }]
         @fetch_missing_args = args.delete('fetch_missing_args')
         @fetch_missing_args = true if @fetch_missing_args.nil?
 
@@ -287,7 +288,7 @@ module Sidekiq
         if args["message"]
           @message = args["message"]
           message_data = Sidekiq.load_json(@message) || {}
-          @queue = message_data['queue'] || default
+          @queue = message_data['queue'] || "default"
         elsif @klass
           message_data = {
             "class" => @klass.to_s,
@@ -296,24 +297,25 @@ module Sidekiq
 
           #get right data for message
           #only if message wasn't specified before
-          message_data = case @klass
+          klass_data = case @klass
             when Class
-              @klass.get_sidekiq_options.merge(message_data)
+              @klass.get_sidekiq_options
             when String
               begin
-                @klass.constantize.get_sidekiq_options.merge(message_data)
-              rescue
+                Sidekiq::Cron::Support.constantize(@klass).get_sidekiq_options
+              rescue Exception => e
                 #Unknown class
-                message_data.merge("queue"=>"default")
+                {"queue"=>"default"}
               end
           end
 
+          message_data = klass_data.merge(message_data)
           #override queue if setted in config
           #only if message is hash - can be string (dumped JSON)
           if args['queue']
             @queue = message_data['queue'] = args['queue']
           else
-            @queue = message_data['queue'] || default
+            @queue = message_data['queue'] || "default"
           end
 
           #dump message as json
@@ -397,7 +399,7 @@ module Sidekiq
         else
           begin
             cron = Rufus::Scheduler::CronLine.new(@cron)
-            cron.next_time(Time.now)
+            cron.next_time(Time.now.utc).utc
           rescue Exception => e
             #fix for different versions of cron-parser
             if e.message == "Bad Vixie-style specification bad"
@@ -445,12 +447,19 @@ module Sidekiq
           conn.hmset redis_key, *hash_to_redis(to_hash)
 
           #add information about last time! - don't enque right after scheduler poller starts!
-          time = Time.now
+          time = Time.now.utc
           conn.zadd(job_enqueued_key, time.to_f.to_s, formated_last_time(time).to_s) unless conn.exists(job_enqueued_key)
         end
         logger.info { "Cron Jobs - add job with name: #{@name}" }
       end
 
+      def save_last_enqueue_time
+        Sidekiq.redis do |conn|
+          # update last enqueue time
+          conn.hset redis_key, 'last_enqueue_time', @last_enqueue_time
+        end
+      end
+
       # remove job from cron jobs by name
       # input:
       #   first arg: name (string) - name of job (must be same - case sensitive)
@@ -486,15 +495,15 @@ module Sidekiq
 
       # Parse cron specification '* * * * *' and returns
       # time when last run should be performed
-      def last_time now = Time.now
-        Rufus::Scheduler::CronLine.new(@cron).previous_time(now)
+      def last_time now = Time.now.utc
+        Rufus::Scheduler::CronLine.new(@cron).previous_time(now.utc).utc
       end
 
-      def formated_enqueue_time now = Time.now
+      def formated_enqueue_time now = Time.now.utc
         last_time(now).getutc.to_f.to_s
       end
 
-      def formated_last_time now = Time.now
+      def formated_last_time now = Time.now.utc
         last_time(now).getutc.iso8601
       end
 
@@ -542,7 +551,7 @@ module Sidekiq
       end
 
       def not_past_scheduled_time?(current_time)
-        last_cron_time = Rufus::Scheduler::CronLine.new(@cron).previous_time(current_time)
+        last_cron_time = Rufus::Scheduler::CronLine.new(@cron).previous_time(current_time).utc
         return false if (current_time.to_i - last_cron_time.to_i) > 60
         true
       end
