@@ -5,11 +5,14 @@ require 'sidekiq/scheduled'
 
 module Sidekiq
   module Cron
+    POLL_INTERVAL = 30
+
     # The Poller checks Redis every N seconds for sheduled cron jobs
     class Poller < Sidekiq::Scheduled::Poller
       def enqueue
+        time = Time.now.utc
         Sidekiq::Cron::Job.all.each do |job|
-          enqueue_job(job)
+          enqueue_job(job, time)
         end
       rescue => ex
         # Most likely a problem with redis networking.
@@ -20,13 +23,17 @@ module Sidekiq
 
       private
 
-      def enqueue_job(job)
-        job.test_and_enque_for_time! Time.now if job && job.valid?
+      def enqueue_job(job, time = Time.now.utc)
+        job.test_and_enque_for_time! time if job && job.valid?
       rescue => ex
         # problem somewhere in one job
         logger.error "CRON JOB: #{ex.message}"
         logger.error "CRON JOB: #{ex.backtrace.first}"
       end
+
+      def poll_interval_average
+         Sidekiq.options[:poll_interval] || POLL_INTERVAL
+      end
     end
   end
 end
