@@ -22,6 +22,8 @@ require 'shoulda-context'
 require "rack/test"
 require "mocha/setup"
 
+ENV['RACK_ENV'] = 'test'
+
 #SIDEKIQ Require - need to have sidekiq running!
 require 'sidekiq'
 require 'sidekiq/util'
@@ -30,7 +32,7 @@ require 'sidekiq/web'
 Sidekiq.logger.level = Logger::ERROR
 
 require 'sidekiq/redis_connection'
-redis_url = ENV['REDIS_URL'] || 'redis://localhost/15'
+redis_url = ENV['REDIS_URL'] || 'redis://0.0.0.0:6379'
 REDIS = Sidekiq::RedisConnection.create(:url => redis_url, :namespace => 'testy')
 
 Sidekiq.configure_client do |config|
@@ -42,9 +44,11 @@ $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
 $LOAD_PATH.unshift(File.dirname(__FILE__))
 require 'sidekiq-cron'
 require 'sidekiq/cron/web'
+require 'pp'
 
 class CronTestClass
   include Sidekiq::Worker
+  sidekiq_options retry: true
 
   def perform args = {}
     puts "super croned job #{args}"
@@ -53,9 +57,38 @@ end
 
 class CronTestClassWithQueue
   include Sidekiq::Worker
-  sidekiq_options :queue => :super, :retry => false, :backtrace => true
+  sidekiq_options queue: :super, retry: false, backtrace: true
 
   def perform args = {}
     puts "super croned job #{args}"
   end
 end
+
+module ActiveJob
+  class Base
+    def self.queue_name_prefix
+      @queue_name_prefix
+    end
+
+    def self.queue_name_prefix=(queue_name_prefix)
+      @queue_name_prefix = queue_name_prefix
+    end
+
+    def self.set(options)
+      @queue = options['queue']
+
+      self
+    end
+
+    def self.perform_later(*args)
+      {
+        "job_class"  => self.class.name,
+        "queue_name" => @queue,
+        "args"  => [*args],
+      }
+    end
+  end
+end
+
+class ActiveJobCronTestClass < ActiveJob::Base
+end
